<a href="dryx-open:///Users/Dave/Dropbox/notes/taskpaper/thespacedoctor-projects.taskpaper" title="open taskpaper"><i class="fa fa-check-square-o" aria-hidden="true"></i></a> <<EvernoteNotebook()>> <<ExternalPageLink("https://github.com/thespacedoctor/astronotes-wiki/tree/master",<i class="fa fa-github" aria-hidden="true" alt-text="reveal in github"></i>, "reveal in github")>> <<RevealLocally(1)>> <<OpenLocally(1)>> <<DownloadThisPage(1)>> <<Dropbox(1)>> <<MailPlane()>><br><strong>tags:</strong><<Tags(1)>>

[[_TOC_]]

